==> claws-mail_2.10.0.orig.tar.gz: claws-mail-2.10.0/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Ho Vit Dinh <hoa@users.sf.net>",
"Werner Koch <wk@gnupg.org>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Martin Schaaf <mascha1@users.sf.net>",
"Fabien Vantard <fzzzzz@gmail.com>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Carsten Schurig",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] Tim <timbrain@post.cz>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[el] Stavros Giannouris <stavrosg2002@freemail.gr>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Fabien Vantard <fzzzzz@gmail.com>",
"[hr] Dragan <drleskov@inet.hr>",
"[hu] Pader Rezso <rezso@rezso.net>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] Rui Hirokawa <rui_hirokawa@ybb.ne.jp>",
"[ko] SungHyun Nam <namsh@kldp.org>",
"[nb] Geir Helland <pjallabais@users.sf.net>",
"[nl] Tim Dijkstra <tim@famdijkstra.org>",
"[pl] Emilian Nowak <eminowbl@posejdon.wpk.p.lodz.pl>",
"[pl] Quar <Quar@sylpheed.quar.org>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[ru] Pavlo Bohmat <bohm@ukr.net>",
"[sk] Andrej Kacian <andrej@kacian.sk>",
"[sr] Aleksandar Urosevic <urke@users.sf.net>",
"[sv] Anders Trobck <sylpheed@troback.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
"[zh_TW] Wei-Lun Chao <chaoweilun@pcmail.com.tw>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Pawel Pekala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Jean-Luc Biord",
"Eugene Brevdo",
"Andr Filipe de Assuno e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Frste",
"Stoyan Genov",
"Thomas Gilgin",
"Thierry Godefroy",
"Alex Gorbachenko",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Ales Nosek",
"James Noyes",
"Jens Oberender",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Pawel Pkala",
"Don Quijote",
"Jens Rantil",
"Michael Rasmussen",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"shigeri",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skytt",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Tsutsui",
"Aleksandar Urosevic",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gl Zoltn",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail_3.6.1.orig.tar.gz: claws-mail-3.6.1/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Ho Vit Dinh <hoa@users.sf.net>",
"Werner Koch <wk@gnupg.org>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>", 
"Fabien Vantard <fzzzzz@gmail.com>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"[hu] Pader Rezso <rezso@rezso.net>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[pl] Emilian Nowak <eminowbl@posejdon.wpk.p.lodz.pl>",
"[pl] Quar <Quar@sylpheed.quar.org>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[sk] Andrej Kacian <andrej@kacian.sk>",
"[sr] Aleksandar Urosevic <urke@users.sf.net>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Pawel Pekala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Jean-Luc Biord",
"Eugene Brevdo",
"Andr Filipe de Assuno e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Jonathan Corbet",
"Christian Cornelssen",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Frank Dietrich",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Frste",
"Stoyan Genov",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Federico Heinz",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jrme Lelong",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Ales Nosek",
"James Noyes",
"Jens Oberender",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Pawel Pkala",
"Don Quijote",
"Jens Rantil",
"Michael Rasmussen",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"shigeri",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skytt",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Tsutsui",
"Aleksandar Urosevic",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gl Zoltn",
"Marien Zwart",
"Martin Zwickel",
NULL
};
